@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.9002';
+our $VERSION = '0.9100';
 
 use warnings;
 use strict;
@@ -206,6 +206,22 @@ sub path_cost {
 }
 
 
+sub MST_edge_sum {
+    my ($self, $tree) = @_;
+
+    my $sum = 0;
+
+    my @edges = split /,/, $tree;
+
+    for my $edge (@edges) {
+        my @edge = split /=/, $edge;
+        $sum += $self->get_cost(\@edge);
+    }
+
+    return $sum;
+}
+
+
 sub dump {
     my $self = shift;
     my $attr = shift || 'weight';
@@ -240,7 +256,7 @@ Graph::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.9002
+version 0.9100
 
 =head1 SYNOPSIS
 
@@ -277,6 +293,9 @@ version 0.9002
 
  $cost = $gw->path_cost( [0, 3, 1, 2], $attr );
 
+ my $tree = $gw->MST_Kruskal;
+ my $sum = $gw->MST_edge_sum($tree);
+
 =head1 DESCRIPTION
 
 A C<Graph::Weighted> object is a subclass of the L<Graph> module with attribute
@@ -346,6 +365,12 @@ Return the summed weight (or cost attribute) of the path edges.
 For the cost of the shortest path, please see C<path_length> under
 L<Graph/"All-Pairs Shortest Paths (APSP)">.
 
+=head2 MST_edge_sum
+
+  $sum = $gw->MST_edge_sum($tree);
+
+Compute the sum of the edges of a minimum-spanning-tree.
+
 =head2 dump
 
   $gw->dump
